@@ -16,17 +16,21 @@
 #'
 #' @return data.frame with list of stations and related metadata
 #'
+#' @export
+#'
 #' @examples
-#' # Retrieve all the stations in the network
-#' # x <- catalogue()
+#' \dontrun{
+#'   # Retrieve all the stations in the network
+#'   x <- catalogue()
 #'
-#' # Define a bounding box:
-#' bbox <- list(lonMin=-3.82, lonMax=-3.63, latMin=52.43, latMax=52.52)
-#' # Get stations within the bounding box
-#' x <- catalogue(bbox)
+#'   # Define a bounding box:
+#'   bbox <- list(lonMin=-3.82, lonMax=-3.63, latMin=52.43, latMax=52.52)
+#'   # Get stations within the bounding box
+#'   x <- catalogue(bbox)
 #'
-#' # Get stations based on minimum number of recording years
-#' # x <- catalogue(minRec=30)
+#'   # Get stations based on minimum number of recording years
+#'   x <- catalogue(minRec=30)
+#' }
 #'
 
 catalogue <- function(bbox = NULL, columnName = NULL, columnValue = NULL,
@@ -61,12 +65,12 @@ catalogue <- function(bbox = NULL, columnName = NULL, columnValue = NULL,
   url <- paste(website,"/json/stationSummary?db=nrfa_public&stn=llbb:",
                latMax,",",lonMin,",",latMin,",",lonMax, sep="")
 
-  if( url.exists(url) ) {
+  if( RCurl::url.exists(url) ) {
 
     # Get the JSON file
-    stationListJSON <- fromJSON(file=url)
+    stationListJSON <- rjson::fromJSON(file=url)
     # remove nested lists
-    stationList <- llply(stationListJSON, unlist)
+    stationList <- plyr::llply(stationListJSON, unlist)
 
     if (length(stationListJSON) == 0) {
 
