@@ -12,10 +12,12 @@
 #' @return list composed of as many objects as in the list of station identification numbers. Each object can be accessed using their names or index (e.g. x[[1]], x[[2]], and so forth). Each object contains a zoo time series.
 #'
 #' @examples
-#' # getTS(18019, type = "cmr")
-#' # getTS(c(54022,54090,54091), type = "cmr")
-#' # getTS(18019, type = "gdf")
-#' # getTS(c(54022,54090,54091), type = "gdf")
+#' \dontrun{
+#'   getTS(18019, type = "cmr")
+#'   getTS(c(54022,54090,54091), type = "cmr")
+#'   getTS(18019, type = "gdf")
+#'   getTS(c(54022,54090,54091), type = "gdf")
+#' }
 #'
 
 getTS <- function(id, type, metadata = FALSE, parallel = FALSE){
@@ -68,11 +70,11 @@ getTS_internal <- function(idx, type, metadata){
   myURL <- paste(website,"/xml/waterml2?db=nrfa_public&stn=",
                  idx, "&dt=", type, sep="")
 
-  if ( url.exists(myURL) ){
+  if ( RCurl::url.exists(myURL) ){
 
-    doc <- urlsToDocs(myURL)
-    nodes <- docsToNodes(doc,xpath="/")
-    myList <- nodesToList(nodes)
+    doc <- XML2R::urlsToDocs(myURL)
+    nodes <- XML2R::docsToNodes(doc,xpath="/")
+    myList <- XML2R::nodesToList(nodes)
 
     data <- FindTS(myList)
     if (metadata) meta <- FindInfo(myList)
