@@ -10,8 +10,12 @@
 #'
 #' @return Plot rainfall and flow for a given station
 #'
+#' @export
+#'
 #' @examples
-#' # plotRainFlow(id = 54090)
+#' \dontrun{
+#'   plotRainFlow(id = 54090)
+#' }
 
 plotRainFlow <- function(id = NULL,
                          rain = NULL, flow = NULL, area = NULL, title = ""){
@@ -37,36 +41,41 @@ plotRainFlow <- function(id = NULL,
   proportion <- ceiling((max(convertedFlow, na.rm = T) -
                            min(convertedFlow, na.rm = T))/3)
 
-  # opar <- par()
-  par(mar=c(2,4,3,4))
+  # opar <- graphics::par()
+  graphics::par(mar=c(4,4,4,4))
 
-  plot(convertedFlow, ylim =c(-proportion/2,max(convertedFlow)+proportion),
-       main=title, xlab="",ylab="Flow [mm/d]", lwd=0.5)
+  xts::plot.xts(convertedFlow,
+                ylim =c(-proportion/2,max(convertedFlow)+proportion),
+                main=title, xlab="",ylab="Flow [mm/d]",
+                auto.grid = FALSE, minor.ticks = FALSE, major.ticks = "years",
+                major.format = "%Y")
 
   # Add precipitation to the top
-  par(bty="n", new=T)
-  plot(rain, type="h",
-       ylim=rev(range(rain)*5), # downward bars
-       yaxt="n", xaxt="n", ann=F, # do not plot x and y axis
-       lwd=0.5, col="deepskyblue3" ) # suggested cosmetics
+  graphics::par(bty="n", new=T)
+  graphics::plot(rain, type="h", main="",
+                 ylim=rev(range(rain)*5), # downward bars
+                 yaxt="n", xaxt="n", ann=F, # do not plot x and y axis
+                 auto.grid = FALSE, minor.ticks = FALSE,
+                 col="deepskyblue3" ) # suggested cosmetics
 
   # add right axis (4) to describe P
-  axis(4, pretty(range(rain))[c(2,4,6,8)],
-       col.axis="deepskyblue3", col="deepskyblue3", las=1, cex.axis=0.8 )
-  mtext("Rain [mm/month]", side = 4, line = 3, cex = par("cex.lab"),
-        col="deepskyblue3", adj = 1)
+  graphics::axis(4, pretty(range(rain))[c(2,4,6,8)],
+                 col.axis="deepskyblue3", col="deepskyblue3", las=1,
+                 cex.axis=0.8 )
+  graphics::mtext("Rain [mm/month]", side = 4, line = 3, cex = graphics::par("cex.lab"),
+                  col="deepskyblue3", adj = 1)
   # reset border and overlay
-  par(bty="o", new=F)
+  graphics::par(bty="o", new=F)
 
-  legend("bottom",
-         c("GDF", "CMR"),
-         horiz = TRUE,
-         y.intersp=1,
-         bty = "n",
-         lwd =c(3, 2),
-         col = c("black","deepskyblue3"),
-         cex = 1)
+  graphics::legend("bottom",
+                   c("GDF", "CMR"),
+                   horiz = TRUE,
+                   y.intersp=1,
+                   bty = "n",
+                   lwd =c(3, 2),
+                   col = c("black","deepskyblue3"),
+                   cex = 1)
 
-  # par() <- opar
+  # graphics::par() <- opar
 
 }
